<?php
/**
 * Custom meta box post style.
 */

/**
 * Get the post style based on the given post ID.
 */
function editorpro_get_post_style( $post_id ) {

	// Get the post layout.
	$style = get_post_meta( $post_id, '_editorpro_post_style', true );

	// Return the layout if one is found.  Otherwise, return 'default'.
	return ( !empty( $style ) ? $style : 'default' );
}

/**
 * Registers new meta box.
 */
function editorpro_post_styles_box() {

	$screens = [ 'post' ];
	$screens = apply_filters( 'editorpro_post_styles_screen', $screens );
	foreach ( $screens as $screen ) {
		add_meta_box(
			'editorpro_post_styles',              // Unique ID
			esc_html__( 'Styles', 'editorpro' ),  // Box title
			'editorpro_post_styles_html',         // Content callback, must be of type callable
			$screen,                              // Post type
			'side'                                // Context
		);
	}

}
add_action( 'add_meta_boxes', 'editorpro_post_styles_box' );

/**
 * Displays the content of the meta boxes.
 */
function editorpro_post_styles_html( $post ) {
	$post_layout = editorpro_get_post_style( $post->ID );
	wp_nonce_field( 'editorpro_post_style_save', 'editorpro_post_style_nonce' );
?>

	<p><?php esc_html_e( 'Setup the style for this post.', 'editorpro' ); ?>
	<p>
		<label>
			<input type="radio" name="editorpro_post_style" id="editorpro_post_style" value="default" <?php checked( $post_layout, 'default' ); ?> />
			<?php esc_html_e( 'Default', 'editorpro' ); ?>
		</label>
	</p>
	<p>
		<label>
			<input type="radio" name="editorpro_post_style" id="editorpro_post_style" value="full-width-title" <?php checked( $post_layout, 'full-width-title' ); ?> />
			<?php esc_html_e( 'Full Width Title', 'editorpro' ); ?>
		</label>
	</p>
	<p>
		<label>
			<input type="radio" name="editorpro_post_style" id="editorpro_post_style" value="side-by-side" <?php checked( $post_layout, 'side-by-side' ); ?> />
			<?php esc_html_e( 'Side by Side', 'editorpro' ); ?>
		</label>
	</p>
	<p>
		<label>
			<input type="radio" name="editorpro_post_style" id="editorpro_post_style" value="full-width-side-by-side" <?php checked( $post_layout, 'full-width-side-by-side' ); ?> />
			<?php esc_html_e( 'Full Width Side by Side', 'editorpro' ); ?>
		</label>
	</p>
	<p>
		<label>
			<input type="radio" name="editorpro_post_style" id="editorpro_post_style" value="thumbnail-overlay" <?php checked( $post_layout, 'thumbnail-overlay' ); ?> />
			<?php esc_html_e( 'Thumbnail Overlay', 'editorpro' ); ?>
		</label>
	</p>
	<p>
		<label>
			<input type="radio" name="editorpro_post_style" id="editorpro_post_style" value="full-width-thumbnail-overlay" <?php checked( $post_layout, 'full-width-thumbnail-overlay' ); ?> />
			<?php esc_html_e( 'Full Width Thumbnail Overlay', 'editorpro' ); ?>
		</label>
	</p>
	<p>
		<label>
			<input type="radio" name="editorpro_post_style" id="editorpro_post_style" value="thumbnail-on-top" <?php checked( $post_layout, 'thumbnail-on-top' ); ?> />
			<?php esc_html_e( 'Thumbnail on Top', 'editorpro' ); ?>
		</label>
	</p>
	<p>
		<label>
			<input type="radio" name="editorpro_post_style" id="editorpro_post_style" value="full-width-thumbnail-on-top" <?php checked( $post_layout, 'full-width-thumbnail-on-top' ); ?> />
			<?php esc_html_e( 'Full Width Thumbnail on Top', 'editorpro' ); ?>
		</label>
	</p>
<?php
}

/**
 * Saves the metadata.
 */
function editorpro_post_styles_box_save( $post_id, $post ) {

	// Bail if we're doing an auto save
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )
		return;

	// if our nonce isn't there, or we can't verify it, bail
	if ( ! isset( $_POST['editorpro_post_style_nonce'] ) || ! wp_verify_nonce( $_POST['editorpro_post_style_nonce'], 'editorpro_post_style_save' ) )
		return;

	// if our current user can't edit this post, bail
	if ( ! current_user_can( 'edit_posts' ) )
		return;

	// Get the meta key.
	$meta_key = '_editorpro_post_style';

	// Get the previous post layout.
	$meta_value = editorpro_get_post_style( $post_id );

	// Get the submitted post layout.
	$new_meta_value = $_POST['editorpro_post_style'];

	// If there is no new meta value but an old value exists, delete it.
	if ( current_user_can( 'delete_post_meta', $post_id, $meta_key ) && '' == $new_meta_value && $meta_value )
		delete_post_meta( $post_id, $meta_key );

	// If a new meta value was added and there was no previous value, add it.
	elseif ( current_user_can( 'add_post_meta', $post_id, $meta_key ) && $new_meta_value && '' == $meta_value )
		update_post_meta( $post_id, $meta_key, $new_meta_value );

	// If the old layout doesn't match the new layout, update the post layout meta.
	elseif ( current_user_can( 'edit_post_meta', $post_id, $meta_key ) && $meta_value !== $new_meta_value )
		update_post_meta( $post_id, $meta_key, $new_meta_value );

}
add_action( 'save_post', 'editorpro_post_styles_box_save', 10, 2 );
